import {
  select,
  csv,
  scaleOrdinal,
  schemeSet2,
  format
} from 'd3';

import { colorLegend } from './colorLegend';
import { loadAndProcessData } from './loadAndProcessData';
import { scatterplot } from './scatterplot';

const colorScale = scaleOrdinal();
const colorValue = d => d.country;
let category;

let selectedCountry;
let data;

//svg initialize
const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

//margins
const margin = { top: 60, right: 30, bottom: 88, left: 200 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
const title = 'GDP Variation: USA and Germany';

const scatterG = svg.append('g')
  .attr('transform', `translate(${margin.left},${margin.top})`);
const colorLegendG = svg.append('g')
  .attr('transform', `translate(20, 70)`);

  svg.append('text')
    .attr('class', 'title')
    .attr('x', (width + margin.left) / 2)
    .attr('y', 45)
    .text(title);

 //data loading concept from Nick Lima
loadData().then(processedData => {
  data = processedData;
  category = [...new Set(data.map(d => d.country))];
  var artistPlays = {};
  category.forEach(a => { artistPlays[a] = 0; });
  data.forEach(d => { artistPlays[d.country] += d.plays; });


  var sortable = [];
  for (var artist in artistPlays) {
      sortable.push([artist, artistPlays[artist]]);
  }
  sortable.sort((a, b) => { return b[1] - a[1]; });
  artists = sortable.map(d => d[0]);
  render();
});



const colorScale = scaleOrdinal();
const colorValue = d => d.country;

const onClick = d => {
  selectedCountry = d;
  render();
};

const render = () => {
  colorScale
    .domain(category)
    .range(schemeSet2); 
  
 
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius:9,
    spacing: 20,
    textOffset: 12,
    backgroundRectWidth: 135,
    onClick,
    selectedCountry
  });
  
  scatterG.call(scatterplot, {
    data,
    colorScale,
    colorValue,
    selectedCountry,
    innerWidth,
    innerHeight,
    circleRadius: 8
  });
};
 
